==> eossdk-1.17.1.3.0-sources.jar: host/anzo/eossdk/eos/sdk/anticheat/server/options/EOS_AntiCheatServer_ProtectMessageOptions.java <==
package host.anzo.eossdk.eos.sdk.anticheat.server.options;

import com.sun.jna.Memory;
import com.sun.jna.Pointer;
import com.sun.jna.Structure;
import host.anzo.eossdk.eos.sdk.anticheat.common.EOS_AntiCheatCommon_ClientHandle;
import org.jetbrains.annotations.NotNull;

import static com.sun.jna.Structure.FieldOrder;

/**
 * @author Anton Lasevich
 * @since 8/5/2023
 */
@FieldOrder({"ApiVersion", "ClientHandle", "DataLengthBytes", "Data", "OutBufferSizeBytes"})
public class EOS_AntiCheatServer_ProtectMessageOptions extends Structure {
	public static int EOS_ANTICHEATSERVER_PROTECTMESSAGE_API_LATEST = 1;

	/** API Version: Set this to {@link #EOS_ANTICHEATSERVER_PROTECTMESSAGE_API_LATEST}. */
	public int ApiVersion;
	/** Locally unique value describing the remote user to whom the message will be sent */
	public EOS_AntiCheatCommon_ClientHandle ClientHandle;
	/** Length in bytes of input */
	public int DataLengthBytes;
	/** The data to encrypt */
	public Pointer Data;
	/** The size in bytes of OutBuffer */
	public int OutBufferSizeBytes;

	public EOS_AntiCheatServer_ProtectMessageOptions() {
		super();
		ApiVersion = EOS_ANTICHEATSERVER_PROTECTMESSAGE_API_LATEST;
	}

	public EOS_AntiCheatServer_ProtectMessageOptions(Pointer peer) {
		super(peer);
	}

	public static class ByReference extends EOS_AntiCheatServer_ProtectMessageOptions implements Structure.ByReference {
		public ByReference(EOS_AntiCheatCommon_ClientHandle clientHandle, byte @NotNull [] data, int outBufferSizeBytes) {
			super();
			ClientHandle = clientHandle;
			Data = new Memory(data.length);
			Data.write(0, data, 0, data.length);
			DataLengthBytes = data.length;
			OutBufferSizeBytes = outBufferSizeBytes;
		}
	}

	public static class ByValue extends EOS_AntiCheatServer_ProtectMessageOptions implements Structure.ByValue {
	}
}

==> eossdk-1.18.0.4.0-sources.jar: host/anzo/eossdk/eos/sdk/anticheat/server/options/EOS_AntiCheatServer_ProtectMessageOptions.java <==
package host.anzo.eossdk.eos.sdk.anticheat.server.options;

import com.sun.jna.Memory;
import com.sun.jna.Pointer;
import com.sun.jna.Structure;
import host.anzo.eossdk.eos.sdk.EOSLibrary;
import host.anzo.eossdk.eos.sdk.anticheat.common.EOS_AntiCheatCommon_ClientHandle;
import org.jetbrains.annotations.NotNull;

import static com.sun.jna.Structure.FieldOrder;

/**
 * Input parameters for the {@link EOSLibrary#EOS_AntiCheatServer_ProtectMessage} function.
 * @author Anton Lasevich
 * @since 8/5/2023
 */
@FieldOrder({"ApiVersion", "ClientHandle", "DataLengthBytes", "Data", "OutBufferSizeBytes"})
public class EOS_AntiCheatServer_ProtectMessageOptions extends Structure {
	/** The most recent version of the EOS_AntiCheatServer_ProtectMessage API. */
	public static int EOS_ANTICHEATSERVER_PROTECTMESSAGE_API_LATEST = 1;

	/** API Version: Set this to {@link #EOS_ANTICHEATSERVER_PROTECTMESSAGE_API_LATEST}. */
	public int ApiVersion;
	/** Locally unique value describing the remote user to whom the message will be sent */
	public EOS_AntiCheatCommon_ClientHandle ClientHandle;
	/** Length in bytes of input */
	public int DataLengthBytes;
	/** The data to encrypt */
	public Pointer Data;
	/** The size in bytes of OutBuffer */
	public int OutBufferSizeBytes;

	public EOS_AntiCheatServer_ProtectMessageOptions() {
		super();
		ApiVersion = EOS_ANTICHEATSERVER_PROTECTMESSAGE_API_LATEST;
	}

	public EOS_AntiCheatServer_ProtectMessageOptions(Pointer peer) {
		super(peer);
	}

	public static class ByReference extends EOS_AntiCheatServer_ProtectMessageOptions implements Structure.ByReference {
		public ByReference(EOS_AntiCheatCommon_ClientHandle clientHandle, byte @NotNull [] data, int outBufferSizeBytes) {
			super();
			ClientHandle = clientHandle;
			Data = new Memory(data.length);
			Data.write(0, data, 0, data.length);
			DataLengthBytes = data.length;
			OutBufferSizeBytes = outBufferSizeBytes;
		}
	}

	public static class ByValue extends EOS_AntiCheatServer_ProtectMessageOptions implements Structure.ByValue {
	}
}
